@@ -99,7 +99,7 @@ AppMenuWidget::AppMenuWidget()
     // Freestyle mode ----------------------------
     m_Freestyle = new QPushButton(this);
     m_Freestyle->setObjectName(QStringLiteral("m_Freestyle"));
-    m_Freestyle->setToolTip(i18n("Open standard KBruch"));
+    m_Freestyle->setToolTip(i18nc("@info:tooltip", "Open standard KBruch"));
     m_Freestyle->setFixedSize(QSize(150, 197));
     gridLayout->addWidget(m_Freestyle, 1, 0, Qt::AlignCenter);
 
@@ -114,7 +114,7 @@ AppMenuWidget::AppMenuWidget()
     // Learning mode ----------------------------
     m_Learning = new QPushButton(this);
     m_Learning->setObjectName(QStringLiteral("m_Learning"));
-    m_Learning->setToolTip(i18n("Open learning KBruch"));
+    m_Learning->setToolTip(i18nc("@info:tooltip", "Open learning KBruch"));
     m_Learning->setFixedSize(QSize(150, 197));
     gridLayout->addWidget(m_Learning, 1, 1, Qt::AlignCenter);
 
