@@ -38,7 +38,7 @@ public:
     explicit TaskWidget(QWidget * parent = nullptr, const Task &para_task = Task());
 
     /** destructor */
-    ~TaskWidget();
+    ~TaskWidget() override;
 
     /** set the task to be displayed */
     void setTask(const Task &para_task);
@@ -53,7 +53,7 @@ private:
     bool m_questionMixed;
 
     /** overriding the paint event of FractionBaseWidget */
-    void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent*) override;
 };
 
 #endif
